@@ -53,8 +53,6 @@ typedef struct {
 	PanelAppletOrient  orient;
 } Fish;
 
-GtkWidget *bah_window = NULL;
-
 /*
  * set_access_name_desc
  * Description : Set Accessible Name and Description.
@@ -252,9 +250,9 @@ load_image_file (Fish *fish)
 	if (fish->pix)
 		gdk_pixmap_unref (fish->pix);
 
-	g_assert (bah_window && bah_window->window);
-
 	frames = panel_applet_gconf_get_int (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
+	if (frames <= 0)
+		frames = 1;
 
 	tmp = panel_applet_gconf_get_string (PANEL_APPLET (fish->applet), FISH_PREFS_IMAGE, NULL);
 	if (g_path_is_absolute (tmp)) {
@@ -285,10 +283,8 @@ load_image_file (Fish *fish)
 			fish->w = frames * fish->size;
 			fish->h = fish->size;
 		}
-
- 		fish->pix = gdk_pixmap_new (bah_window->window,
+ 		fish->pix = gdk_pixmap_new (GDK_ROOT_PARENT (),
 					    fish->w, fish->h, -1);
-
 		return;
 	}
 
@@ -353,7 +349,7 @@ load_image_file (Fish *fish)
 	fish->w = w;
 	fish->h = h;
 
-	fish->pix = gdk_pixmap_new (bah_window->window,
+	fish->pix = gdk_pixmap_new (GDK_ROOT_PARENT (),
 				    fish->w,fish->h,-1);
 
 	gc = gdk_gc_new (fish->pix);
@@ -381,6 +377,8 @@ setup_size (Fish *fish)
 	gint frames;
 
 	frames = panel_applet_gconf_get_int (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
+	if (frames <= 0)
+		frames = 1;
 
 	if (fish_applet_rotate (fish)) {
 		GTK_WIDGET (fish->darea)->requisition.width = fish->w;
@@ -417,6 +415,8 @@ fish_draw (GtkWidget *darea,
 		return;
 
 	frames = panel_applet_gconf_get_int (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
+	if (frames <= 0)
+		frames = 1;
 
 	if (fish_applet_rotate (fish))
 		gdk_draw_pixmap (fish->darea->window,
@@ -466,6 +466,8 @@ fish_timeout(gpointer data)
 		gint frames;
 
 		frames = panel_applet_gconf_get_int (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
+		if (frames <= 0)
+			frames = 1;
 
 		fish->curpix++;
 		if (fish->curpix >= frames)
@@ -506,7 +508,7 @@ apply_dialog_properties (Fish *fish)
 static void
 apply_properties (Fish *fish) 
 {
-	gdouble     speed;
+	gdouble speed;
 
 	apply_dialog_properties (fish);
 	
@@ -518,6 +520,8 @@ apply_properties (Fish *fish)
 		gtk_timeout_remove (fish->timeout_id);
 
 	speed = panel_applet_gconf_get_float (PANEL_APPLET (fish->applet), FISH_PREFS_SPEED, NULL);
+	if (speed <= 0)
+		speed = 1.0;
 
         fish->timeout_id = gtk_timeout_add (speed * 1000, fish_timeout, fish);
 	fish->curpix = 0;
@@ -618,8 +622,9 @@ phelp (void)
 {
 	GError *error = NULL;
 
-	gnome_help_display_desktop (NULL, "fish_applet", "fish_applet", "FISH-PREFS", &error);
-	if (error != NULL) {
+	gnome_help_display_desktop (
+		NULL, "fish-applet-2", "fish-applet-2", NULL, &error);
+	if (error) {
 		g_warning ("help error: %s\n", error->message);
 		g_error_free (error);
 	}
@@ -830,27 +835,51 @@ display_properties_dialog (BonoboUIComponent *uic,
 	g_free (command);
 }
 
+static void
+something_fishy_going_on (const char *message)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new (NULL,
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_CLOSE,
+					 message);
+
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (gtk_widget_destroy),
+			  NULL);
+
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_widget_show (dialog);
+}
+
 static gchar *
 fish_locate_fortune_command (Fish *fish)
 {
-	gchar *command;
-	gchar *tmp;
+	char *retval = NULL;
 
-	tmp = panel_applet_gconf_get_string (PANEL_APPLET (fish->applet), FISH_PREFS_COMMAND, NULL);
-	if (!tmp)
+	retval = panel_applet_gconf_get_string (PANEL_APPLET (fish->applet), FISH_PREFS_COMMAND, NULL);
+	if (!retval) {
+		something_fishy_going_on (_("Unable to get the name of the command to execute"));
 		return NULL;
+	}
 
-	if (g_path_is_absolute (tmp))
-		return tmp;
+	if (!g_path_is_absolute (retval)) {
+		char *tmp;
 
-	command = g_find_program_in_path (tmp);
-	g_free (tmp);
+		tmp = retval;
+		retval = g_find_program_in_path (tmp);
+		g_free (tmp);
+	}
 
-	if (!command)
-		if (g_file_test ("/usr/games/fortune", G_FILE_TEST_EXISTS))
-			command = g_strdup ("/usr/games/fortune");
+	if (!retval && g_file_test ("/usr/games/fortune", G_FILE_TEST_EXISTS))
+		retval = g_strdup ("/usr/games/fortune");
 
-	return command;
+	if (!retval)
+		something_fishy_going_on (_("Unable to locate the command to execute"));
+
+	return retval;
 }
 
 static void
@@ -895,8 +924,14 @@ delete_event (GtkWidget *w, gpointer data)
 static void 
 update_fortune_dialog (Fish *fish)
 {
-	char *fortune_command;
-	gchar *output = NULL;
+	GError *error = NULL;
+	char   *fortune_command;
+	char   *output = NULL;
+	char   *output_utf8;
+
+	fortune_command = fish_locate_fortune_command (fish);
+	if (!fortune_command)
+		return;
 
 	if ( fish->fortune_dialog == NULL ) {
 		GtkWidget *view;
@@ -963,14 +998,28 @@ update_fortune_dialog (Fish *fish)
 
 	text_clear (fish);
 
-	fortune_command = fish_locate_fortune_command (fish);
+	g_spawn_command_line_sync (fortune_command, &output, NULL, NULL, &error);
+	if (error) {
+		char *message;
 
-	g_spawn_command_line_sync (fortune_command, &output, NULL, NULL, NULL);
+		message = g_strdup_printf (_("Unable to execute '%s'\n\nDetails : %s"),
+					   fortune_command, error->message);
+		something_fishy_going_on (message);
+		g_free (message);
+		g_error_free (error);
+	}
 	
 	g_free (fortune_command);
 
-	if (output) {
-		insert_text (fish, output);
+	/* The output is not guarantied to be in UTF-8 format, most
+	   likely it's just in ASCII-7 or in the user locale */
+	if (!g_utf8_validate (output, -1, NULL))
+	  output_utf8 = g_locale_to_utf8 (output, -1, NULL, NULL, NULL);
+	else
+	  output_utf8 = g_strdup (output);
+
+	if (output_utf8) {
+		insert_text (fish, output_utf8);
 	} else {
 		insert_text (fish, 
 			     _("You do not have fortune installed "
@@ -978,7 +1027,8 @@ update_fortune_dialog (Fish *fish)
 			       "to run.\n\nPlease refer to fish "
 			       "properties dialog."));
 	}
-
+	g_free (output);
+	g_free (output_utf8);
 }
 
 static void
@@ -1049,9 +1099,11 @@ fish_expose (GtkWidget      *darea,
 	     GdkEventExpose *event,
 	     Fish           *fish)
 {
-	gint frames;
+	int frames;
 
 	frames = panel_applet_gconf_get_int (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
+	if (frames <= 0)
+		frames = 1;
 
 	if (fish_applet_rotate (fish))
 		gdk_draw_pixmap (fish->darea->window,
@@ -1082,7 +1134,11 @@ create_fish_widget(Fish *fish)
 	frames = panel_applet_gconf_get_int   (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
 	speed  = panel_applet_gconf_get_float (PANEL_APPLET (fish->applet), FISH_PREFS_SPEED, NULL);
 
-	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
+	/* Sanity checking */
+	if (frames <= 0)
+		frames = 1;
+	if (speed <= 0)
+		speed = 1.0;
 
 	fish->darea = gtk_drawing_area_new();
 
@@ -1120,8 +1176,6 @@ create_fish_widget(Fish *fish)
         fish->timeout_id = gtk_timeout_add (speed * 1000, fish_timeout, fish);
 
         gtk_container_add(GTK_CONTAINER(fish->frame),fish->darea);
-        
-        gtk_widget_pop_colormap ();
 }
 
 static void
@@ -1131,8 +1185,9 @@ display_help_dialog (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	gnome_help_display_desktop (NULL, "fish_applet", "fish_applet", NULL, &error);
-	if (error != NULL) {
+	gnome_help_display_desktop (
+		NULL, "fish-applet-2", "fish-applet-2", NULL, &error);
+	if (error) {
 		g_warning ("help error: %s\n", error->message);
 		g_error_free (error);
 	}
@@ -1179,7 +1234,7 @@ display_about_dialog (BonoboUIComponent *uic,
 	}
 		
 	fish->aboutbox =
-		gnome_about_new (_("The GNOME Fish Applet"),
+		gnome_about_new (_("Fish"),
 				 "3.4.7.4ac19",
 				 "(C) 1998 the Free Software Foundation",
 				 _("This applet has no use what-so-ever. "
@@ -1316,17 +1371,6 @@ fish_applet_fill (PanelApplet *applet)
 
 	panel_applet_add_preferences (applet, "/schemas/apps/fish_applet/prefs", NULL);
 
-	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
-
-	bah_window = gtk_window_new (GTK_WINDOW_POPUP);
-
-	gtk_widget_pop_colormap ();
-
-	gtk_widget_set_uposition (bah_window,
-				  gdk_screen_width () + 1,
-				  gdk_screen_height () + 1);
-	gtk_widget_show_now (bah_window);
-
 	fish->frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (fish->frame), GTK_SHADOW_IN);
 
