@@ -18,7 +18,6 @@
 #include "drawer.h"
 #include "launcher.h"
 #include "logout.h"
-#include "menu-properties.h"
 #include "menu-util.h"
 #include "menu.h"
 #include "panel-config.h"
@@ -180,33 +179,21 @@ applet_remove_callback (GtkWidget  *widget,
 }
 
 static void
-applet_callback_callback(GtkWidget *widget, gpointer data)
+applet_callback_callback (GtkWidget      *widget,
+			  AppletUserMenu *menu)
 {
-	AppletUserMenu *menu = data;
+	g_return_if_fail (menu->info != NULL);
 
-	g_return_if_fail(menu->info != NULL);
-
-	switch(menu->info->type) {
+	switch (menu->info->type) {
 	case APPLET_LAUNCHER:
-		if (strcmp (menu->name, "properties") == 0) {
+		if (!strcmp (menu->name, "properties"))
 			launcher_properties (menu->info->data);
-		} else if (strcmp (menu->name, "help") == 0) {
+
+		else if (!strcmp (menu->name, "help"))
 			panel_show_help ("wgospanel.xml", "gospanel-16");
-		} else if (strcmp (menu->name, "help_on_app") == 0) {
-			Launcher * launcher = menu->info->data;
-			if (launcher->ditem != NULL) {
-				GError *error = NULL;
-				const char *docpath =
-					gnome_desktop_item_get_string
-					    (launcher->ditem, "DocPath");
-				if ( ! panel_show_gnome_kde_help (docpath, &error)) {
-					panel_error_dialog ("cannot_show_gnome_kde_help",
-							    _("<b>Cannot display help document</b>\n\n"
-							      "Details: %s"), error->message);
-					g_clear_error (&error);
-				}
-			}
-		}
+
+		else if (!strcmp (menu->name, "help_on_app"))
+			launcher_show_help (menu->info->data);
 		break;
 	case APPLET_DRAWER: 
 		if (strcmp (menu->name, "properties")==0) {
@@ -218,10 +205,7 @@ applet_callback_callback(GtkWidget *widget, gpointer data)
 		}
 		break;
 	case APPLET_MENU:
-		if(strcmp(menu->name,"properties")==0)
-			menu_properties(menu->info->data);
-
-		else if (strcmp (menu->name, "help") == 0) {
+		if (strcmp (menu->name, "help") == 0) {
 			panel_show_help ("wgospanel.xml", "gospanel-37");
 		}
 		break;
@@ -400,16 +384,16 @@ setup_an_item(AppletUserMenu *menu,
 		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menu->menuitem);
 
 	/*if an item not a submenu*/
-	if(!is_submenu) {
-		g_signal_connect(G_OBJECT(menu->menuitem), "activate",
-				 G_CALLBACK (applet_callback_callback),
-				   menu);
-		g_signal_connect(G_OBJECT (submenu), "destroy",
-				 G_CALLBACK (gtk_widget_destroyed),
-				 &menu->submenu);
+	if (!is_submenu) {
+		g_signal_connect (menu->menuitem, "activate",
+				  G_CALLBACK (applet_callback_callback),
+				  menu);
+		g_signal_connect (submenu, "destroy",
+				  G_CALLBACK (gtk_widget_destroyed),
+				  &menu->submenu);
 	/* if the item is a submenu and doesn't have it's menu
 	   created yet*/
-	} else if(!menu->submenu) {
+	} else if (!menu->submenu) {
 		menu->submenu = panel_menu_new ();
 	}
 
@@ -674,7 +658,9 @@ applet_destroy (GtkWidget *w, AppletInfo *info)
 
 		location = gnome_desktop_item_get_location (launcher->ditem);
 
-		session_add_dead_launcher (location);
+		/* Launcher may not yet have been hoarded */
+		if (location)
+			session_add_dead_launcher (location);
 	}
 
 
@@ -806,7 +792,11 @@ panel_applet_load_from_unique_id (AppletType   type,
 	temp_key = panel_applet_get_full_gconf_key (
 			type, profile, unique_id, "object_type");
 	type_string = gconf_client_get_string (gconf_client, temp_key, NULL);
-
+	if (!type_string) {
+		g_printerr (_("No object_type set for panel object with ID %s\n"), unique_id);
+		return;
+	}
+        
 	if (!gconf_string_to_enum (object_type_enum_map,
 				   type_string,
 				   (int *) &applet_type)) {
@@ -824,7 +814,11 @@ panel_applet_load_from_unique_id (AppletType   type,
 	temp_key = panel_applet_get_full_gconf_key (
 			type, profile, unique_id, "panel_id");
 	panel_id = gconf_client_get_string (gconf_client, temp_key, NULL);
-
+	if (!panel_id) {
+		g_printerr (_("No panel_id set for panel object with ID %s\n"), unique_id);
+		return;
+	}
+        
 	temp_key = panel_applet_get_full_gconf_key (
 			type, profile, unique_id, "panel_right_stick");
 	right_stick = gconf_client_get_bool (gconf_client, temp_key, NULL);
@@ -832,10 +826,8 @@ panel_applet_load_from_unique_id (AppletType   type,
 	panel_widget = panel_widget_get_by_id (panel_id);
 	g_free (panel_id);
 
-	if (!panel_widget) {
-		g_warning ("panel_applet_load: can't find the panel for this object\n");
+	if (!panel_widget)
 		return;
-	}
 
 	if (right_stick)
 		position = panel_widget->size - position;
@@ -962,7 +954,7 @@ panel_applet_save_position (AppletInfo *applet_info,
 	client  = panel_gconf_get_client ();
 	profile = panel_gconf_get_profile ();
 
-	right_stick = panel_applet_get_right_stick (applet_info);
+	right_stick = panel_is_applet_right_stick (applet_info->widget);
 	temp_key = panel_applet_get_full_gconf_key (
 			applet_info->type, profile, gconf_key, "panel_right_stick");
 	gconf_client_set_bool (client, temp_key, right_stick, NULL);
@@ -1206,16 +1198,3 @@ panel_applet_get_panel_id (AppletInfo *applet)
 
 	return panel->unique_id;
 }
-
-gboolean
-panel_applet_get_right_stick (AppletInfo *applet)
-{
-	PanelWidget *panel;
-
-	g_return_val_if_fail (applet != NULL, FALSE);
-	g_return_val_if_fail (G_IS_OBJECT (applet->widget), FALSE);
-
-	panel = PANEL_WIDGET (applet->widget->parent);
-
-	return panel_widget_is_applet_stuck (panel, applet->widget);
-}
