@@ -2,6 +2,9 @@
 #define PANEL_UTIL_H
 
 #include <gtk/gtk.h>
+#include <gdk/gdk.h>
+
+#include <libgnome/gnome-desktop-item.h>
 
 #include "panel-widget.h"
 #include "panel-config-global.h"
@@ -74,6 +77,14 @@ GtkWidget *	panel_error_dialog	(const char *class,
 GtkWidget *	panel_info_dialog	(const char *class,
 					 const char *format,
 					 ...) G_GNUC_PRINTF (2, 3);
+GtkWidget *	panel_error_dialog_with_parent (GtkWindow *parent,
+						const char *class,
+						const char *format,
+						...) G_GNUC_PRINTF (3, 4);
+GtkWidget *	panel_info_dialog_with_parent (GtkWindow *parent,
+					       const char *class,
+					       const char *format,
+					       ...) G_GNUC_PRINTF (3, 4);
 
 gboolean	is_ext			(const char *file,
 					 const char *ext);
@@ -125,6 +136,7 @@ gboolean	panel_ensure_dir	(const char *dirname);
 gboolean	panel_is_uri_writable	(const char *uri);
 gboolean	panel_uri_exists	(const char *uri);
 
+
 /* GnomeVFS reading utils */
 
 typedef struct _ReadBuf ReadBuf;
@@ -143,7 +155,7 @@ void		readbuf_close		(ReadBuf *rb);
 void add_atk_name_desc (GtkWidget *widget, gchar *name, gchar *desc);
 void set_relation (GtkWidget *widget, GtkLabel *label, int set_for);
 
-/* FIXME : make battery stuff public as appropriate */
+GdkPixbuf *	missing_pixbuf		(int size);
 
 
 G_END_DECLS
